import { registerExtension } from 'vscode/extensions';

const manifest = {"name":"ng-template","displayName":"Angular Language Service","description":"Editor services for Angular templates","version":"17.3.1","publisher":"Angular","icon":"angular.png","license":"MIT","keywords":["Angular","multi-root ready"],"engines":{"vscode":"^1.74.3"},"capabilities":{"untrustedWorkspaces":{"supported":true},"virtualWorkspaces":{"supported":"limited","description":"The Language Server Protocol does not support remote file systems. Functionality is limited to syntax highlighting only."}},"categories":["Programming Languages"],"contributes":{"configuration":{"title":"Angular Language Service","properties":{"angular.log":{"type":"string","enum":["off","terse","normal","verbose"],"default":"off","description":"Enables logging of the Angular server to a file. This log can be used to diagnose Angular Server issues. The log may contain file paths, source code, and other potentially sensitive information from your project."},"angular.view-engine":{"type":"boolean","default":false,"description":"Use legacy View Engine language service. This option is incompatible with projects using Angular v13 and above."},"angular.enable-strict-mode-prompt":{"type":"boolean","default":true,"markdownDescription":"Prompt to enable the [strictTemplates](https://angular.io/guide/angular-compiler-options#stricttemplates) flag in [angularCompilerOptions](https://angular.io/guide/angular-compiler-options). Note that strict mode is only available when using Ivy."},"angular.trace.server":{"type":"string","scope":"window","enum":["off","messages","verbose"],"default":"off","description":"Traces the communication between VS Code and the Angular language server."},"angular.suggest.includeAutomaticOptionalChainCompletions":{"type":"boolean","default":true,"markdownDescription":"Enable showing completions on potentially undefined values that insert an optional chain call. Requires TS 3.7+ and strict null checks to be enabled."},"angular.suggest.includeCompletionsWithSnippetText":{"type":"boolean","default":true,"markdownDescription":"Enable snippet completions from Angular language server. Requires using TypeScript 4.3+ in the workspace."},"angular.forceStrictTemplates":{"type":"boolean","default":false,"markdownDescription":"Enabling this option will force the language service to use [strictTemplates](https://angular.io/guide/angular-compiler-options#stricttemplates) and ignore the user settings in the `tsconfig.json`."}}},"grammars":[{"path":"./syntaxes/inline-template.json","scopeName":"inline-template.ng","injectTo":["source.ts"],"embeddedLanguages":{"text.html":"html","source.css":"css","source.js":"javascript"}},{"path":"./syntaxes/inline-styles.json","scopeName":"inline-styles.ng","injectTo":["source.ts"],"embeddedLanguages":{"source.css.scss":"scss"}},{"path":"./syntaxes/template.json","scopeName":"template.ng","injectTo":["text.html.derivative","source.ts"],"embeddedLanguages":{"text.html":"html","source.css":"css"}},{"path":"./syntaxes/template-blocks.json","scopeName":"template.blocks.ng","injectTo":["text.html.derivative","source.ts"],"embeddedLanguages":{"text.html":"html","expression.ng":"javascript"}},{"path":"./syntaxes/template-tag.json","scopeName":"template.tag.ng","injectTo":["text.html.derivative","source.ts"]},{"path":"./syntaxes/expression.json","scopeName":"expression.ng"}]},"repository":{"type":"git","url":"https://github.com/angular/vscode-ng-language-service"}};

const { registerFileUrl, whenReady } = registerExtension(manifest, undefined, {"system":true,"readmePath":"README.md","changelogPath":"CHANGELOG.md"});


registerFileUrl('README.md', '../assets/Angular.ng-template-17.3.1.vsix/README.md', 'text/markdown');

registerFileUrl('CHANGELOG.md', '../assets/Angular.ng-template-17.3.1.vsix/CHANGELOG.md', 'text/markdown');

registerFileUrl('syntaxes/inline-template.json', '../assets/Angular.ng-template-17.3.1.vsix/inline-template.json', 'application/json');

registerFileUrl('syntaxes/inline-styles.json', '../assets/Angular.ng-template-17.3.1.vsix/inline-styles.json', 'application/json');

registerFileUrl('syntaxes/template.json', '../assets/Angular.ng-template-17.3.1.vsix/template.json', 'application/json');

registerFileUrl('syntaxes/template-blocks.json', '../assets/Angular.ng-template-17.3.1.vsix/template-blocks.json', 'application/json');

registerFileUrl('syntaxes/template-tag.json', '../assets/Angular.ng-template-17.3.1.vsix/template-tag.json', 'application/json');

registerFileUrl('syntaxes/expression.json', '../assets/Angular.ng-template-17.3.1.vsix/expression.json', 'application/json');

registerFileUrl('package.json', '../assets/Angular.ng-template-17.3.1.vsix/package.json', 'application/json');

registerFileUrl('angular.png', '../assets/Angular.ng-template-17.3.1.vsix/angular.png', 'image/png');

export { whenReady };
