import { registerExtension } from 'vscode/extensions';

const manifest = {"name":"svlangserver","description":"A language server for systemverilog","keywords":["sv","systemverilog","verilog","language","server"],"version":"0.4.1","author":"Kanad Kanhere","publisher":"IMCTradingBV","license":"MIT","repository":{"type":"git","url":"https://github.com/imc-trading/svlangserver.git"},"engines":{"node":"*","vscode":"^1.52.0"},"icon":"resources/icon.png","categories":["Programming Languages","Snippets","Linters","Formatters"],"extensionKind":["workspace"],"bin":{"svlangserver":"./bin/main.js"},"contributes":{"languages":[{"id":"systemverilog","aliases":["SystemVerilog","systemverilog","System Verilog","Systemverilog"],"extensions":[".sv",".svh"],"configuration":"./language-configuration.json"},{"id":"verilog","aliases":["Verilog","verilog"],"extensions":[".v",".vh"],"configuration":"./language-configuration.json"}],"snippets":[{"language":"systemverilog","path":"./snippets/systemverilog.json"},{"language":"verilog","path":"./snippets/systemverilog.json"}],"grammars":[{"language":"systemverilog","scopeName":"source.systemverilog","path":"./syntaxes/systemverilog.tmLanguage.json"},{"language":"verilog","scopeName":"source.systemverilog","path":"./syntaxes/systemverilog.tmLanguage.json"},{"scopeName":"markdown.verilog.codeblock","path":"./syntaxes/codeblock.json","injectTo":["text.html.markdown"],"embeddedLanguages":{"meta.embedded.block.systemverilog":"source.systemverilog","meta.embedded.block.verilog":"source.verilog"}}],"configuration":[{"title":"SystemVerilog Language Server","properties":{"systemverilog.includeIndexing":{"type":"array","default":["**/*.sv"],"description":"Files included for indexing (glob pattern)."},"systemverilog.mustIncludeIndexing":{"type":"array","default":[],"description":"Files included for indexing and are always to be linted (glob pattern)."},"systemverilog.libraryIndexing":{"type":"array","default":[],"description":"Files not included for indexing but needed for linting (glob pattern)."},"systemverilog.excludeIndexing":{"type":"array","default":["**/test/**"],"description":"Files excluded for indexing (glob pattern)."},"systemverilog.linter":{"type":"string","enum":["icarus","verilator"],"default":"verilator","description":"Linter to use"},"systemverilog.launchConfiguration":{"type":"string","default":"verilator -sv --lint-only --Wall","description":"Command used for linting","examples":["verilator -sv --lint-only --Wall","iverilog -t null"]},"systemverilog.defines":{"type":"array","default":[],"description":"Defines needed for linting."},"systemverilog.lintOnUnsaved":{"type":"boolean","default":true,"description":"Enable linting on unsaved files"},"systemverilog.linterWhitelist":{"type":"array","default":["/Unsupported: Interfaced port on top level module/i","/Parent instance's interface is not found/i"],"description":"List of linting errors that need to be whitelisted (javascript regex)"},"systemverilog.formatCommand":{"type":"string","default":"verible-verilog-format","description":"Verible verilog format command"},"systemverilog.disableCompletionProvider":{"type":"boolean","default":false,"description":"Disable auto completion provided by the language server"},"systemverilog.disableHoverProvider":{"type":"boolean","default":false,"description":"Disable hover over help provided by the language server"},"systemverilog.disableSignatureHelpProvider":{"type":"boolean","default":false,"description":"Disable signature help provided by the language server"},"systemverilog.disableLinting":{"type":"boolean","default":false,"description":"Disable verilator linting"}}}],"jsonValidation":[{"fileMatch":"tasks.json","url":"./schemas/tasks.schema.json"}],"problemMatchers":[{"name":"verilator-error","owner":"Verilator","source":"systemverilog","severity":"error","fileLocation":"autoDetect","pattern":[{"regexp":"%Error(-[A-Z0-9]+)?: ((\\S+):(\\d+):((\\d+):)? )?(.*)$","severity":1,"file":2,"line":3,"column":4,"message":5}]},{"name":"verilator-warning","owner":"Verilator","source":"systemverilog","severity":"warning","fileLocation":"autoDetect","pattern":[{"regexp":"%Warning(-[A-Z0-9]+)?: ((\\S+):(\\d+):((\\d+):)? )?(.*)$","severity":1,"file":2,"line":3,"column":4,"message":5}]}]},"files":["/lib/*.js","/lib/*.d.ts","/bin/*.js"]};

const { registerFileUrl, whenReady } = registerExtension(manifest, undefined, {"system":true,"readmePath":"README.md","changelogPath":"CHANGELOG.md"});


registerFileUrl('README.md', '../assets/IMCTradingBV.svlangserver-0.4.1.vsix/README.md', 'text/markdown');

registerFileUrl('CHANGELOG.md', '../assets/IMCTradingBV.svlangserver-0.4.1.vsix/CHANGELOG.md', 'text/markdown');

registerFileUrl('syntaxes/systemverilog.tmLanguage.json', '../assets/IMCTradingBV.svlangserver-0.4.1.vsix/systemverilog.tmLanguage.json', 'application/json');

registerFileUrl('syntaxes/codeblock.json', '../assets/IMCTradingBV.svlangserver-0.4.1.vsix/codeblock.json', 'application/json');

registerFileUrl('language-configuration.json', '../assets/IMCTradingBV.svlangserver-0.4.1.vsix/language-configuration.json', 'application/json');

registerFileUrl('snippets/systemverilog.json', '../assets/IMCTradingBV.svlangserver-0.4.1.vsix/systemverilog.json', 'application/json');

registerFileUrl('schemas/tasks.schema.json', '../assets/IMCTradingBV.svlangserver-0.4.1.vsix/tasks.schema.json', 'application/json');

registerFileUrl('package.json', '../assets/IMCTradingBV.svlangserver-0.4.1.vsix/package.json', 'application/json');

registerFileUrl('resources/icon.png', '../assets/IMCTradingBV.svlangserver-0.4.1.vsix/icon.png', 'image/png');

export { whenReady };
