import { registerExtension } from 'vscode/extensions';

const manifest = {"name":"erlang","description":"Erlang language extension for Visual Studio Code","version":"0.9.9","icon":"images/icon.png","publisher":"pgourlain","engines":{"vscode":"^1.52.0"},"categories":["Programming Languages","Snippets","Debuggers"],"contributes":{"languages":[{"id":"erlang","aliases":["Erlang","erlang"],"extensions":[".erl",".hrl",".xrl",".yrl",".es",".escript",".app.src","rebar.config"],"configuration":"./erlang.configuration.json","icon":{"dark":"images/erlang-fileicon-dark.png","light":"images/erlang-fileicon-light.png"}}],"grammars":[{"language":"erlang","scopeName":"source.erlang","path":"./grammar/Erlang.plist"}],"snippets":[{"language":"erlang","path":"./snippets/erlang.json"}],"configuration":{"type":"object","title":"Erlang","properties":{"erlang.erlangPath":{"type":"string","default":"","description":"Directory where erl/escript are located. Leave empty to use default."},"erlang.erlangArgs":{"type":"array","items":{"type":"string","title":"argument","default":""},"default":[],"description":"Arguments passed to Erlang backend. Leave empty unless you really have to tweak the Erlang VM."},"erlang.erlangDistributedNode":{"type":"boolean","description":"Start the Erlang backend in a distributed Erlang node. Could be usefull for extension development. Note, it starts EPMD if not running yet.","default":false},"erlang.rebarPath":{"type":"string","default":"","description":"Directory where rebar/rebar3 are located. Leave empty to use default."},"erlang.rebarBuildArgs":{"type":"array","items":{"type":"string","title":"argument","default":""},"default":["compile"],"description":"Arguments passed to rebar/rebar3 build command."},"erlang.includePaths":{"type":"array","items":{"type":"string","title":"path","default":""},"default":[],"description":"Include paths used when extension analyses the sources. Paths are read from rebar.config, and also standard set of paths is used. This setting is for special cases when the default behaviour is not enough."},"erlang.linting":{"type":"boolean","default":true,"description":"Enable/disable dynamic validation of opened Erlang source files."},"erlang.codeLensEnabled":{"type":"boolean","default":false,"description":"Enable/disable references CodeLens on functions."},"erlang.inlayHintsEnabled":{"type":"boolean","default":false,"description":"Enable/disable references InlayHints on functions."},"erlang.verbose":{"type":"boolean","description":"Enable/disable technical traces for use in the extension development.","default":false},"erlang.debuggerRunMode":{"type":"string","default":"external","description":"Specifies how to run vscode debugadapter. Useful in extension development.","enum":["external","server","inline"],"enumDescriptions":["external : launch debug adapter in separate process","server: launch debugadapter as a socket based server","inline: launch debugadapter in current process"]},"erlang.formattingLineLength":{"type":"number","default":100,"description":"Maximum line length for document formatting."}}},"problemMatchers":[{"name":"erlang","owner":"erlang","fileLocation":["relative","${workspaceRoot}"],"pattern":{"regexp":"^(.*):(\\d+):\\s+((Warning): )?(.*)$","file":1,"line":2,"severity":4,"message":5}}]},"repository":{"type":"git","url":"https://github.com/pgourlain/vscode_erlang.git"},"license":"MIT"};

const { registerFileUrl, whenReady } = registerExtension(manifest, undefined, {"system":true,"readmePath":"README.md","changelogPath":"CHANGELOG.md"});


registerFileUrl('README.md', '../assets/pgourlain.erlang-0.9.9.vsix/README.md', 'text/markdown');

registerFileUrl('CHANGELOG.md', '../assets/pgourlain.erlang-0.9.9.vsix/CHANGELOG.md', 'text/markdown');

registerFileUrl('grammar/Erlang.plist', '../assets/pgourlain.erlang-0.9.9.vsix/Erlang.plist');

registerFileUrl('images/erlang-fileicon-dark.png', '../assets/pgourlain.erlang-0.9.9.vsix/erlang-fileicon-dark.png', 'image/png');

registerFileUrl('images/erlang-fileicon-light.png', '../assets/pgourlain.erlang-0.9.9.vsix/erlang-fileicon-light.png', 'image/png');

registerFileUrl('erlang.configuration.json', '../assets/pgourlain.erlang-0.9.9.vsix/erlang.configuration.json', 'application/json');

registerFileUrl('snippets/erlang.json', '../assets/pgourlain.erlang-0.9.9.vsix/erlang.json', 'application/json');

registerFileUrl('package.json', '../assets/pgourlain.erlang-0.9.9.vsix/package.json', 'application/json');

registerFileUrl('images/icon.png', '../assets/pgourlain.erlang-0.9.9.vsix/icon.png', 'image/png');

export { whenReady };
